@@ -172,7 +172,7 @@ class Lupusec:
     ):  # we are trimming the json from Lupusec heavily, since its bullcrap
         response = self._request_get("panelCondGet")
         if response.status_code != 200:
-            raise Exception("Unable to get panel " + response.status_code)
+            raise Exception("Unable to get panel " + str(response.status_code))
         panel = self.clean_json(response.text)["updates"]
         panel["mode"] = panel[self.api_mode]
         panel.pop(self.api_mode)
